@@ -1,173 +1,178 @@
-//! An attribute macro for easily writing [extension trait pattern][rfc0445].
-//!
-//! ```toml
-//! [dependencies]
-//! easy-ext = "1"
-//! ```
-//!
-//! *Compiler support: requires rustc 1.31+*
-//!
-//! # Examples
-//!
-//! ```rust
-//! use easy_ext::ext;
-//!
-//! #[ext(ResultExt)]
-//! pub impl<T, E> Result<T, E> {
-//!     fn err_into<U>(self) -> Result<T, U>
-//!     where
-//!         E: Into<U>,
-//!     {
-//!         self.map_err(Into::into)
-//!     }
-//! }
-//! ```
-//!
-//! Code like this will be generated:
-//!
-//! ```rust
-//! pub trait ResultExt<T, E> {
-//!     fn err_into<U>(self) -> Result<T, U>
-//!     where
-//!         E: Into<U>;
-//! }
-//!
-//! impl<T, E> ResultExt<T, E> for Result<T, E> {
-//!     fn err_into<U>(self) -> Result<T, U>
-//!     where
-//!         E: Into<U>,
-//!     {
-//!         self.map_err(Into::into)
-//!     }
-//! }
-//! ```
-//!
-//! You can elide the trait name.
-//!
-//! ```rust
-//! use easy_ext::ext;
-//!
-//! #[ext]
-//! impl<T, E> Result<T, E> {
-//!     fn err_into<U>(self) -> Result<T, U>
-//!     where
-//!         E: Into<U>,
-//!     {
-//!         self.map_err(Into::into)
-//!     }
-//! }
-//! ```
-//!
-//! Note that in this case, `#[ext]` assigns a random name, so you cannot
-//! import/export the generated trait.
-//!
-//! ## Visibility
-//!
-//! There are two ways to specify visibility.
-//!
-//! ### Impl-level visibility
-//!
-//! The first way is to specify visibility at the impl level. For example:
-//!
-//! ```rust
-//! use easy_ext::ext;
-//!
-//! // unnamed
-//! #[ext]
-//! pub impl str {
-//!     fn foo(&self) {}
-//! }
-//!
-//! // named
-//! #[ext(StrExt)]
-//! pub impl str {
-//!     fn bar(&self) {}
-//! }
-//! ```
-//!
-//! ### Associated-item-level visibility
-//!
-//! Another way is to specify visibility at the associated item level.
-//!
-//! For example, if the method is `pub` then the trait will also be `pub`:
-//!
-//! ```rust
-//! use easy_ext::ext;
-//!
-//! #[ext(ResultExt)] // generate `pub trait ResultExt`
-//! impl<T, E> Result<T, E> {
-//!     pub fn err_into<U>(self) -> Result<T, U>
-//!     where
-//!         E: Into<U>,
-//!     {
-//!         self.map_err(Into::into)
-//!     }
-//! }
-//! ```
-//!
-//! This is useful when migrate from an inherent impl to an extension trait.
-//!
-//! Note that the visibility of all the associated items in the `impl` must be identical.
-//!
-//! Note that you cannot specify impl-level visibility and associated-item-level visibility at the same time.
-//!
-//! ## [Supertraits](https://doc.rust-lang.org/reference/items/traits.html#supertraits)
-//!
-//! If you want the extension trait to be a subtrait of another trait,
-//! add `Self: SubTrait` bound to the `where` clause.
-//!
-//! ```rust
-//! use easy_ext::ext;
-//!
-//! #[ext(Ext)]
-//! impl<T> T
-//! where
-//!     Self: Default,
-//! {
-//!     fn method(&self) {}
-//! }
-//! ```
-//!
-//! ## Supported items
-//!
-//! ### [Associated functions (methods)](https://doc.rust-lang.org/reference/items/associated-items.html#associated-functions-and-methods)
-//!
-//! ```rust
-//! use easy_ext::ext;
-//!
-//! #[ext]
-//! impl<T> T {
-//!     fn method(&self) {}
-//! }
-//! ```
-//!
-//! ### [Associated constants](https://doc.rust-lang.org/reference/items/associated-items.html#associated-constants)
-//!
-//! ```rust
-//! use easy_ext::ext;
-//!
-//! #[ext]
-//! impl<T> T {
-//!     const MSG: &'static str = "Hello!";
-//! }
-//! ```
-//!
-//! ### [Associated types](https://doc.rust-lang.org/reference/items/associated-items.html#associated-types)
-//!
-//! ```rust
-//! use easy_ext::ext;
-//!
-//! #[ext]
-//! impl str {
-//!     type Owned = String;
-//!
-//!     fn method(&self) -> Self::Owned {
-//!         self.to_owned()
-//!     }
-//! }
-//! ```
-//!
-//! [rfc0445]: https://github.com/rust-lang/rfcs/blob/HEAD/text/0445-extension-trait-conventions.md
+// SPDX-License-Identifier: Apache-2.0 OR MIT
+
+/*!
+<!-- tidy:crate-doc:start -->
+A lightweight attribute macro for easily writing [extension trait pattern][rfc0445].
+
+```toml
+[dependencies]
+easy-ext = "1"
+```
+
+## Examples
+
+```rust
+use easy_ext::ext;
+
+#[ext(ResultExt)]
+pub impl<T, E> Result<T, E> {
+    fn err_into<U>(self) -> Result<T, U>
+    where
+        E: Into<U>,
+    {
+        self.map_err(Into::into)
+    }
+}
+```
+
+Code like this will be generated:
+
+```rust
+pub trait ResultExt<T, E> {
+    fn err_into<U>(self) -> Result<T, U>
+    where
+        E: Into<U>;
+}
+
+impl<T, E> ResultExt<T, E> for Result<T, E> {
+    fn err_into<U>(self) -> Result<T, U>
+    where
+        E: Into<U>,
+    {
+        self.map_err(Into::into)
+    }
+}
+```
+
+You can elide the trait name.
+
+```rust
+use easy_ext::ext;
+
+#[ext]
+impl<T, E> Result<T, E> {
+    fn err_into<U>(self) -> Result<T, U>
+    where
+        E: Into<U>,
+    {
+        self.map_err(Into::into)
+    }
+}
+```
+
+Note that in this case, `#[ext]` assigns a random name, so you cannot
+import/export the generated trait.
+
+### Visibility
+
+There are two ways to specify visibility.
+
+#### Impl-level visibility
+
+The first way is to specify visibility at the impl level. For example:
+
+```rust
+use easy_ext::ext;
+
+// unnamed
+#[ext]
+pub impl str {
+    fn foo(&self) {}
+}
+
+// named
+#[ext(StrExt)]
+pub impl str {
+    fn bar(&self) {}
+}
+```
+
+#### Associated-item-level visibility
+
+Another way is to specify visibility at the associated item level.
+
+For example, if the method is `pub` then the trait will also be `pub`:
+
+```rust
+use easy_ext::ext;
+
+#[ext(ResultExt)] // generate `pub trait ResultExt`
+impl<T, E> Result<T, E> {
+    pub fn err_into<U>(self) -> Result<T, U>
+    where
+        E: Into<U>,
+    {
+        self.map_err(Into::into)
+    }
+}
+```
+
+This is useful when migrate from an inherent impl to an extension trait.
+
+Note that the visibility of all the associated items in the `impl` must be identical.
+
+Note that you cannot specify impl-level visibility and associated-item-level visibility at the same time.
+
+### [Supertraits](https://doc.rust-lang.org/reference/items/traits.html#supertraits)
+
+If you want the extension trait to be a subtrait of another trait,
+add `Self: SubTrait` bound to the `where` clause.
+
+```rust
+use easy_ext::ext;
+
+#[ext(Ext)]
+impl<T> T
+where
+    Self: Default,
+{
+    fn method(&self) {}
+}
+```
+
+### Supported items
+
+#### [Associated functions (methods)](https://doc.rust-lang.org/reference/items/associated-items.html#associated-functions-and-methods)
+
+```rust
+use easy_ext::ext;
+
+#[ext]
+impl<T> T {
+    fn method(&self) {}
+}
+```
+
+#### [Associated constants](https://doc.rust-lang.org/reference/items/associated-items.html#associated-constants)
+
+```rust
+use easy_ext::ext;
+
+#[ext]
+impl<T> T {
+    const MSG: &'static str = "Hello!";
+}
+```
+
+#### [Associated types](https://doc.rust-lang.org/reference/items/associated-items.html#associated-types)
+
+```rust
+use easy_ext::ext;
+
+#[ext]
+impl str {
+    type Owned = String;
+
+    fn method(&self) -> Self::Owned {
+        self.to_owned()
+    }
+}
+```
+
+[rfc0445]: https://github.com/rust-lang/rfcs/blob/HEAD/text/0445-extension-trait-conventions.md
+
+<!-- tidy:crate-doc:end -->
+*/
 
 #![doc(test(
     no_crate_inject,
@@ -177,16 +182,6 @@
     )
 ))]
 #![forbid(unsafe_code)]
-#![warn(rust_2018_idioms, unreachable_pub)]
-// It cannot be included in the published code because these lints have false positives in the minimum required version.
-#![cfg_attr(test, warn(single_use_lifetimes))]
-#![warn(clippy::pedantic)]
-#![allow(
-    clippy::cast_lossless,
-    clippy::derive_partial_eq_without_eq,
-    clippy::similar_names,
-    clippy::too_many_lines
-)]
 
 // older compilers require explicit `extern crate`.
 #[allow(unused_extern_crates)]
@@ -214,7 +209,7 @@ use crate::{
     to_tokens::ToTokens,
 };
 
-/// An attribute macro for easily writing [extension trait pattern][rfc0445].
+/// A lightweight attribute macro for easily writing [extension trait pattern][rfc0445].
 ///
 /// See crate level documentation for details.
 ///
@@ -267,7 +262,7 @@ fn determine_trait_generics<'a>(
             }
         });
         if let Some(i) = i {
-            let mut params = mem::replace(&mut generics.params, Vec::new());
+            let mut params = mem::replace(&mut generics.params, vec![]);
             let (param, _) = params.remove(i);
             generics.params = params;
 
@@ -313,7 +308,7 @@ fn trait_from_impl(item: &mut ItemImpl, trait_name: Ident) -> Result<ItemTrait>
 
     impl ReplaceParam {
         fn visit_token_stream(&self, tokens: &mut TokenStream) -> bool {
-            let mut out: Vec<TokenTree> = Vec::new();
+            let mut out: Vec<TokenTree> = vec![];
             let mut modified = false;
             let iter = tokens.clone().into_iter();
             for tt in iter {
@@ -401,7 +396,7 @@ fn trait_from_impl(item: &mut ItemImpl, trait_name: Ident) -> Result<ItemTrait>
                                 let mut iter = pred.bounded_ty.clone().into_iter();
                                 if let Some(TokenTree::Ident(i)) = iter.next() {
                                     if iter.next().is_none() && self.self_ty == i.to_string() {
-                                        let bounds = mem::replace(&mut pred.bounds, Vec::new())
+                                        let bounds = mem::replace(&mut pred.bounds, vec![])
                                             .into_iter()
                                             .filter(|(b, _)| !b.is_maybe)
                                             .collect::<Vec<_>>();
@@ -467,9 +462,11 @@ fn trait_from_impl(item: &mut ItemImpl, trait_name: Ident) -> Result<ItemTrait>
         TokenTree::Ident(Ident::new("allow", Span::call_site())),
         TokenTree::Group(Group::new(
             Delimiter::Parenthesis,
-            Some(TokenTree::Ident(Ident::new("patterns_in_fns_without_body", Span::call_site())))
-                .into_iter()
-                .collect(),
+            std::iter::once(TokenTree::Ident(Ident::new(
+                "patterns_in_fns_without_body",
+                Span::call_site(),
+            )))
+            .collect(),
         )),
     ])); // mut self
 
@@ -563,12 +560,13 @@ fn trait_item_from_impl_item(
                     let mut sig = impl_method.sig.clone();
                     for arg in &mut sig.inputs {
                         if let FnArg::Typed(pat, ..) = arg {
-                            *pat = Some(TokenTree::Ident(Ident::new(
-                                "_",
-                                pat.clone().into_iter().next().unwrap().span(),
-                            )))
-                            .into_iter()
-                            .collect();
+                            if pat.to_string() != "self" {
+                                *pat = std::iter::once(TokenTree::Ident(Ident::new(
+                                    "_",
+                                    pat.clone().into_iter().next().unwrap().span(),
+                                )))
+                                .collect();
+                            }
                         }
                     }
                     sig
