@@ -1,6 +1,10 @@
-#![feature(associated_type_bounds)]
+// SPDX-License-Identifier: Apache-2.0 OR MIT
 
-// https://github.com/rust-lang/rust/blob/1.63.0/src/test/ui/associated-type-bounds/fn-where.rs
+#![allow(dead_code)]
+
+// TODO: move to tests/test.rs once Rust 1.79 become stable.
+
+// https://github.com/rust-lang/rust/blob/1.70.0/tests/ui/associated-type-bounds/fn-where.rs
 pub mod fn_where {
     use easy_ext::ext;
 
@@ -50,11 +54,11 @@ pub mod fn_where {
             desugared_bound_region_forall2(beta)
         }
 
-        fn where_contraint_region_forall<B>(beta: B) -> usize
+        fn where_constraint_region_forall<B>(beta: B) -> usize
         where
             for<'a> &'a B: Beta<Gamma: Alpha>,
         {
-            desugared_contraint_region_forall(beta)
+            desugared_constraint_region_forall(beta)
         }
 
         fn where_bound_nested<B>(beta: B) -> usize
@@ -66,7 +70,7 @@ pub mod fn_where {
     }
 }
 
-// https://github.com/rust-lang/rust/blob/1.63.0/src/test/ui/associated-type-bounds/auxiliary/fn-aux.rs
+// https://github.com/rust-lang/rust/blob/1.70.0/tests/ui/associated-type-bounds/auxiliary/fn-aux.rs
 mod fn_aux {
     // Traits:
 
@@ -236,7 +240,7 @@ mod fn_aux {
         assert_forall_epsilon_zeta_satisfies_eta::<B::Gamma>(gamma)
     }
 
-    pub fn desugared_contraint_region_forall<B>(beta: B) -> usize
+    pub fn desugared_constraint_region_forall<B>(beta: B) -> usize
     where
         for<'a> &'a B: Beta,
         for<'a> <&'a B as Beta>::Gamma: Alpha,
