@@ -1,9 +1,11 @@
+// SPDX-License-Identifier: Apache-2.0 OR MIT
+
 #![feature(min_specialization)]
 
 // See also run-pass/specialization.rs.
 
-// https://github.com/rust-lang/rust/blob/1.63.0/src/test/ui/specialization/min_specialization/implcit-well-formed-bounds.rs
-pub mod implcit_well_formed_bounds {
+// https://github.com/rust-lang/rust/blob/1.70.0/tests/ui/specialization/min_specialization/implcit-well-formed-bounds.rs
+pub mod implicit_well_formed_bounds {
     use easy_ext::ext;
 
     struct OrdOnly<T: Ord>(T);
@@ -26,7 +28,7 @@ pub mod implcit_well_formed_bounds {
     }
 }
 
-// https://github.com/rust-lang/rust/blob/1.63.0/src/test/ui/specialization/min_specialization/spec-iter.rs
+// https://github.com/rust-lang/rust/blob/1.70.0/tests/ui/specialization/min_specialization/spec-iter.rs
 pub mod spec_iter {
     use easy_ext::ext;
 
@@ -41,7 +43,7 @@ pub mod spec_iter {
     }
 }
 
-// https://github.com/rust-lang/rust/blob/1.63.0/src/test/ui/specialization/min_specialization/spec-reference.rs
+// https://github.com/rust-lang/rust/blob/1.70.0/tests/ui/specialization/min_specialization/spec-reference.rs
 pub mod spec_reference {
     use easy_ext::ext;
 
