@@ -1,5 +1,15 @@
-#![warn(rust_2018_idioms, single_use_lifetimes)]
-#![allow(clippy::missing_safety_doc)]
+// SPDX-License-Identifier: Apache-2.0 OR MIT
+
+#![allow(
+    dead_code,
+    unreachable_pub,
+    clippy::items_after_statements,
+    clippy::missing_safety_doc,
+    clippy::no_effect_underscore_binding,
+    clippy::undocumented_unsafe_blocks
+)]
+
+use std::{pin::Pin, rc::Rc};
 
 use async_trait::async_trait;
 use easy_ext::ext;
@@ -209,13 +219,11 @@ fn trait_generics() {
     #[ext(Ext2)]
     impl<I: Iterator + ConstInit> I {
         const CONST3: I = {
-            #[allow(dead_code)]
             fn a<I>() {}
             I::INIT1
         };
         type Item4 = I::Item;
         fn method5(self, _: I::Item) -> (Option<I::Item>, <I as Ext2>::Item4) {
-            #[allow(dead_code)]
             fn a<I>() {}
             unimplemented!()
         }
@@ -295,7 +303,7 @@ fn assoc_ty() {
         type Assoc = String;
 
         fn owned(&self) -> Self::Assoc {
-            self.to_string()
+            self.to_owned()
         }
     }
 
@@ -318,6 +326,7 @@ fn assoc_ty() {
     assert_eq!(iter.try_next(), Ok(None));
 }
 
+#[allow(clippy::let_underscore_future)]
 #[test]
 fn syntax() {
     #[ext(E1)]
@@ -369,7 +378,7 @@ fn syntax() {
 fn angle_bracket() {
     #[ext]
     impl fn() -> () {
-        const FUNC: fn(&u8) -> bool = u8::is_ascii as fn(&u8) -> bool;
+        const FUNC: fn() -> fn() -> fn() -> () = Self::func;
         type Func = fn() -> fn() -> ();
         fn func() -> fn() -> fn() -> () {
             || || {}
@@ -475,7 +484,7 @@ fn min_const_generics() {
 
 #[test]
 fn const_generics_defaults() {
-    // https://github.com/rust-lang/rust/tree/1.63.0/src/test/ui/const-generics/defaults
+    // https://github.com/rust-lang/rust/tree/1.70.0/tests/ui/const-generics/defaults
 
     #[ext(Ext)]
     impl<const N: usize = 3> () {}
@@ -487,11 +496,50 @@ fn const_generics_defaults() {
     impl<const N: usize> Trait<N> for () {}
     impl Trait for u8 {}
 
-    // https://github.com/rust-lang/rust/blob/1.63.0/src/test/ui/const-generics/defaults/const-param-as-default-value.rs
+    // https://github.com/rust-lang/rust/blob/1.70.0/tests/ui/const-generics/defaults/const-param-as-default-value.rs
     #[ext(Ext2)]
     impl<const N: usize, const M: usize = N> () {}
 }
 
+#[test]
+fn generic_associated_types() {
+    // https://github.com/rust-lang/rust/blob/1.70.0/tests/ui/generic-associated-types/collections.rs
+
+    trait CollectionFamily {
+        type Member<T>: Collection<T, Family = Self>;
+    }
+
+    struct VecFamily;
+
+    impl CollectionFamily for VecFamily {
+        type Member<T> = Vec<T>;
+    }
+
+    #[ext(Collection)]
+    impl<T> Vec<T> {
+        // TODO: handle where clause in GAT: https://github.com/rust-lang/rust/pull/90076
+        // type Iter<'iter> = std::slice::Iter<'iter, T>
+        // where
+        //     T: 'iter,
+        //     Self: 'iter;
+        type Family = VecFamily;
+        type Sibling<U> = <<Self as Collection<T>>::Family as CollectionFamily>::Member<U>;
+
+        fn empty() -> Self {
+            vec![]
+        }
+
+        fn add(&mut self, value: T) {
+            self.push(value);
+        }
+
+        // TODO: handle where clause in GAT: https://github.com/rust-lang/rust/pull/90076
+        // fn iterate<'iter>(&'iter self) -> Self::Iter<'iter> {
+        //     self.iter()
+        // }
+    }
+}
+
 #[test]
 fn macros() {
     macro_rules! m {
@@ -536,6 +584,7 @@ fn where_clause() {
     }
 }
 
+#[allow(clippy::needless_pub_self)] // This is intentional
 pub mod visibility {
     use easy_ext::ext;
 
@@ -594,3 +643,26 @@ fn arg_pat() {
         }
     }
 }
+
+#[test]
+fn arbitrary_self_types() {
+    #[ext]
+    #[allow(clippy::needless_arbitrary_self_type)]
+    impl String {
+        fn recv(self: Self) {}
+        fn recv_ref(self: &Self) {}
+        fn recv_mut(self: &mut Self) {}
+        fn recv_rc(self: Rc<Self>) {}
+        fn recv_rc_ref(self: &Rc<Self>) {}
+        fn recv_rc_mut(self: &mut Rc<Self>) {}
+        fn recv_pin_box(self: Pin<Box<Self>>) {}
+    }
+
+    String::default().recv();
+    String::default().recv_ref();
+    String::default().recv_mut();
+    Rc::new(String::default()).recv_rc();
+    Rc::new(String::default()).recv_rc_ref();
+    Rc::new(String::default()).recv_rc_mut();
+    Box::pin(String::default()).recv_pin_box();
+}
